@@ -12,7 +12,7 @@ WeightDialog::WeightDialog(QWidget *parent) :
     //setWindowFlags(this->windowFlags() | Qt::Window);
     setWindowTitle("Save weight");
 
-    QHBoxLayout *hLayout = new QHBoxLayout();
+    hLayout = new QHBoxLayout();
     QVBoxLayout *buttonLayout = new QVBoxLayout();
     qDebug () << "WeightDialog::WeightDialog 2";
     modelReps = new QStandardItemModel(this);
@@ -81,6 +81,17 @@ void WeightDialog::load(QString name, QString grp, QString currentSet)
 
     list = xml->getHistoryByExercise(name);
 
+    for(int i = 1; i < currentSet.toInt(); i++)
+    {
+        list.removeFirst();
+        list.removeFirst();
+        list.removeFirst();
+    }
+
+    btnVar->setValueText(list.takeFirst());
+    btnReps->setValueText(list.takeFirst());
+
+
     setWindowTitle("Save weight (set:" + currentSet + ")");
 
     qDebug () << "WeightDialog::load 4";
@@ -88,7 +99,8 @@ void WeightDialog::load(QString name, QString grp, QString currentSet)
 
 void WeightDialog::loadCardio(QString name, QString m, QString s)
 {
-    btnReps->setEnabled(false);
+    hLayout->removeWidget(btnReps);
+    //btnReps->setEnabled(false);
     btnVar->setText("Distance");
     QList <QString> list;
     int select;
@@ -107,6 +119,9 @@ void WeightDialog::loadCardio(QString name, QString m, QString s)
     setWindowTitle("Save distance");
 
 
+    list = xml->getHistoryByExercise(name);
+    btnVar->setValueText(list.takeFirst());
+
 }
 
 void WeightDialog::save()
